import{u as k}from"./router.c3a5f38b.js";import{d as _,L as w,N as d,e as g,W as v,b as a,w as h,u as e,c as p,R as m,o as s,$ as T}from"./vue-router.5e8ba7eb.js";import{K,_ as R,W as I,P,b as S}from"./WorkflowView.5da9d57c.js";import{P as V}from"./api.73862ceb.js";import{A as b,T as W}from"./TabPane.8e50b74a.js";import"./Card.c692bb57.js";import"./fetch.7b08925d.js";import"./linters.fa5f4508.js";import"./asyncComputed.bb3077bb.js";import"./scripts.b9078e95.js";import"./record.98df87df.js";import"./metadata.0a8ceea8.js";import"./PhBug.vue.1aaf96e1.js";import"./PhCheckCircle.vue.0084ae07.js";import"./PhKanban.vue.f8ef7c80.js";import"./PhWebhooksLogo.vue.aa4763f4.js";import"./PhQuestion.vue.e50c85f4.js";import"./ant-design.48d4c5e3.js";import"./index.806e571e.js";import"./index.d0fd73d7.js";import"./index.9f3d447d.js";import"./index.8be952b7.js";import"./CollapsePanel.11bb1d53.js";import"./index.380cef28.js";import"./index.491c020f.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.947570f5.js";import"./model.c9ad3cef.js";import"./workspaces.94798139.js";import"./runnerData.49bf6701.js";import"./url.4683fc99.js";import"./validations.34e5855b.js";import"./string.3bd1e390.js";import"./PhArrowSquareOut.vue.bdda1139.js";import"./index.6a475b9c.js";import"./Badge.1de6f065.js";import"./index.c5acb39e.js";import"./uuid.c1fabc37.js";import"./LoadingOutlined.ddf38866.js";import"./DeleteOutlined.2ed2f157.js";import"./PhDownloadSimple.vue.7a05a0c5.js";import"./utils.1fd79698.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="e79a845a-0ed2-4d55-8f90-3bb7e3db0110",t._sentryDebugIdIdentifier="sentry-dbid-e79a845a-0ed2-4d55-8f90-3bb7e3db0110")}catch{}})();const x={class:"threads-view"},A=_({__name:"Threads",setup(t){const r=k().authHeaders,u=new V(r),i=new P(r),c=new S(r),y=new w(d.array(d.string()),"kanban-selected-stages"),o=g("kanban");return(B,l)=>(s(),v("div",x,[a(e(W),{activeKey:o.value,"onUpdate:activeKey":l[0]||(l[0]=f=>o.value=f)},{default:h(()=>[a(e(b),{key:"kanban",tab:"Kanban View"}),a(e(b),{key:"table",tab:"Table View"}),a(e(b),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(s(),p(K,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(y),"stage-run-repository":e(c)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),o.value==="table"?(s(),p(R,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),o.value==="workflow"?(s(),p(I,{key:2,"kanban-repository":e(i),"workflow-api":e(u)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const he=T(A,[["__scopeId","data-v-86c0b860"]]);export{he as default};
//# sourceMappingURL=Threads.669edafa.js.map
