import{b as o,ey as u,eE as a}from"./vue-router.5e8ba7eb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b1381ee4-a4b8-4b6b-b78e-b7b722b62796",e._sentryDebugIdIdentifier="sentry-dbid-b1381ee4-a4b8-4b6b-b78e-b7b722b62796")}catch{}})();function b(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(i){return Object.getOwnPropertyDescriptor(r,i).enumerable}))),n.forEach(function(i){c(e,i,r[i])})}return e}function c(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var l=function(t,r){var n=b({},t,r.attrs);return o(u,b({},n,{icon:a}),null)};l.displayName="CloseCircleOutlined";l.inheritAttrs=!1;const f=l;export{f as C};
//# sourceMappingURL=CloseCircleOutlined.3dbf2f6b.js.map
