import{C as y}from"./ContentLayout.46908c65.js";import{d as c,L as w,N as l,e as g,c as e,w as b,o as i,b as n,u as o,R as s}from"./vue-router.5e8ba7eb.js";import{K as _,_ as v,W as K,E as R,a as E}from"./WorkflowView.5da9d57c.js";import{E as T}from"./api.73862ceb.js";import{A as p,T as V}from"./TabPane.8e50b74a.js";import"./fetch.7b08925d.js";import"./linters.fa5f4508.js";import"./asyncComputed.bb3077bb.js";import"./scripts.b9078e95.js";import"./record.98df87df.js";import"./metadata.0a8ceea8.js";import"./PhBug.vue.1aaf96e1.js";import"./PhCheckCircle.vue.0084ae07.js";import"./PhKanban.vue.f8ef7c80.js";import"./PhWebhooksLogo.vue.aa4763f4.js";import"./PhQuestion.vue.e50c85f4.js";import"./ant-design.48d4c5e3.js";import"./index.806e571e.js";import"./index.d0fd73d7.js";import"./index.9f3d447d.js";import"./index.8be952b7.js";import"./CollapsePanel.11bb1d53.js";import"./index.380cef28.js";import"./index.491c020f.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.947570f5.js";import"./model.c9ad3cef.js";import"./workspaces.94798139.js";import"./runnerData.49bf6701.js";import"./url.4683fc99.js";import"./validations.34e5855b.js";import"./string.3bd1e390.js";import"./PhArrowSquareOut.vue.bdda1139.js";import"./index.6a475b9c.js";import"./Badge.1de6f065.js";import"./index.c5acb39e.js";import"./Card.c692bb57.js";import"./uuid.c1fabc37.js";import"./LoadingOutlined.ddf38866.js";import"./DeleteOutlined.2ed2f157.js";import"./PhDownloadSimple.vue.7a05a0c5.js";import"./utils.1fd79698.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="8c876d95-8553-42fa-b35c-aa0d3cfd1f3e",r._sentryDebugIdIdentifier="sentry-dbid-8c876d95-8553-42fa-b35c-aa0d3cfd1f3e")}catch{}})();const co=c({__name:"WorkflowThreads",setup(r){const t=new R,m=new E,d=new w(l.array(l.string()),"kanban-selected-stages"),u=new T,a=g("kanban");return(W,f)=>(i(),e(y,{"full-width":""},{default:b(()=>[n(o(V),{activeKey:a.value,"onUpdate:activeKey":f[0]||(f[0]=k=>a.value=k)},{default:b(()=>[n(o(p),{key:"kanban",tab:"Kanban View"}),n(o(p),{key:"table",tab:"Table View"}),n(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),a.value==="kanban"?(i(),e(_,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(d),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),a.value==="table"?(i(),e(v,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),a.value==="workflow"?(i(),e(K,{key:2,"kanban-repository":o(t),"workflow-api":o(u)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{co as default};
//# sourceMappingURL=WorkflowThreads.519d6be0.js.map
