import{u as n}from"./router.c3a5f38b.js";import{r as o,w as a}from"./runnerData.49bf6701.js";import"./vue-router.5e8ba7eb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5bedc036-f672-46be-8ef9-509b22c2eeae",e._sentryDebugIdIdentifier="sentry-dbid-5bedc036-f672-46be-8ef9-509b22c2eeae")}catch{}})();async function i(e){const t=n(),r=await fetch(`/_pages/${e}`,{headers:t.authHeaders});if(r.status===404)return null;if(!r.ok)throw new Error(await r.text());const{form:s}=await r.json();return s?o(s):null}async function d(){const e=n(),t=await fetch("/_workspace",{headers:e.authHeaders});if(t.status!=200)return a({});const r=await t.json();return a(r)}export{i as f,d as g};
//# sourceMappingURL=api.3d221a29.js.map
