import{d as i,r as c,u as a,o as p,c as d,w as m,b as u,R as f,k as l,T as _,m as w,P as g,C as y,M as h,s as k,n as s,p as b,q as v,t as C,v as I}from"./vue-router.5e8ba7eb.js";import{s as W,c as V,a as o}from"./router.c3a5f38b.js";import{W as A}from"./WidgetsFrame.c29eea1f.js";import{u as D}from"./workspaceStore.f173667e.js";import"./api.3d221a29.js";import"./runnerData.49bf6701.js";import"./url.4683fc99.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="0ab802a8-4e3f-4222-8a52-d69343f60d2d",t._sentryDebugIdIdentifier="sentry-dbid-0ab802a8-4e3f-4222-8a52-d69343f60d2d")}catch{}})();const M=i({__name:"App",setup(t){const e=D();return e.actions.fetch(),(n,S)=>{const r=c("RouterView");return a(e).state.workspace?(p(),d(A,{key:0,"main-color":a(e).state.workspace.mainColor,theme:a(e).state.workspace.theme,"font-family":a(e).state.workspace.fontFamily,locale:a(e).state.workspace.language},{default:m(()=>[u(r,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","theme","font-family","locale"])):f("",!0)}}});class P{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await W();const t=V(),e=l({render:()=>b(M)});_.init(),w(e,o),P.init(),e.use(o),e.use(t),e.use(g),e.mount("#app"),e.component("VSelect",y),e.component("Markdown",h),e.component("Message",k),s(e,v),s(e,C),s(e,I)})();
//# sourceMappingURL=player.9ae87eff.js.map
