import{d as t}from"./router.c3a5f38b.js";import{g as s}from"./api.3d221a29.js";import{e as r}from"./vue-router.5e8ba7eb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="03c0724e-f4bc-41f0-865b-11e1392f289d",e._sentryDebugIdIdentifier="sentry-dbid-03c0724e-f4bc-41f0-865b-11e1392f289d")}catch{}})();const c=t("workspace",()=>{const e=r({workspace:null,loading:!1});return{state:e,actions:{async fetch(){e.value.loading=!0,e.value.workspace=await s(),e.value.loading=!1}}}});export{c as u};
//# sourceMappingURL=workspaceStore.f173667e.js.map
