import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.99c7b027.js";import{d as i,eu as s,c as a,u as m,o as c}from"./vue-router.5e8ba7eb.js";import"./gateway.9bb9fef7.js";import"./popupNotifcation.b3ef9d8a.js";import"./fetch.7b08925d.js";import"./record.98df87df.js";import"./SaveButton.8f974eff.js";import"./ExclamationCircleOutlined.7ef2c090.js";import"./CrudView.d77e910d.js";import"./router.1e5228d6.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.af476096.js";import"./BookOutlined.bf415405.js";import"./url.4683fc99.js";import"./PhDotsThree.vue.5061c9cb.js";import"./index.d0fd73d7.js";import"./index.806e571e.js";import"./PhRocketLaunch.vue.dc0dc724.js";import"./asyncComputed.bb3077bb.js";import"./PhPencil.vue.3ceaa978.js";import"./index.c5acb39e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="846b6401-cb46-4ea3-8667-afa09e7f11e5",o._sentryDebugIdIdentifier="sentry-dbid-846b6401-cb46-4ea3-8667-afa09e7f11e5")}catch{}})();const q=i({__name:"EnvVars",setup(o){const r=s().params.projectId,t=new p(r);return(d,f)=>(c(),a(n,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{q as default};
//# sourceMappingURL=EnvVars.919871cb.js.map
