import{eT as t,eU as r}from"./vue-router.5e8ba7eb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="00629eca-271e-4904-8a4a-bcffc5848dee",e._sentryDebugIdIdentifier="sentry-dbid-00629eca-271e-4904-8a4a-bcffc5848dee")}catch{}})();function d(e,n){return t(1,arguments),r(e,Date.now(),n)}export{d as f};
//# sourceMappingURL=index.9f3d447d.js.map
