import{S as s,dp as i}from"./vue-router.5e8ba7eb.js";import{g as c}from"./index.87887dee.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="2e3d417c-2dbd-469d-ba80-e94175d1723e",e._sentryDebugIdIdentifier="sentry-dbid-2e3d417c-2dbd-469d-ba80-e94175d1723e")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:m,TimePicker:f,QuarterPicker:d,RangePicker:o}=c(i),u=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:m,RangePicker:o,TimePicker:f,QuarterPicker:d,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(d.name,d),e)});export{u as D,t as M,d as Q,o as R,r as W};
//# sourceMappingURL=dayjs.acfa1139.js.map
