import{W as g}from"./Watermark.22de2c07.js";import{i as h}from"./metadata.0a8ceea8.js";import{F as k}from"./PhArrowSquareOut.vue.bdda1139.js";import{d as w,eH as x,f as b,u as e,W as m,b as o,w as r,R as v,o as s,c as p,ax as u,cU as f,aJ as C,ew as D,d0 as _,ex as I,et as F,$ as H}from"./vue-router.5e8ba7eb.js";import{u as T}from"./workspaceStore.f173667e.js";import"./index.33d7359b.js";import{C as W}from"./Card.c692bb57.js";import"./router.c3a5f38b.js";import"./PhBug.vue.1aaf96e1.js";import"./PhCheckCircle.vue.0084ae07.js";import"./PhKanban.vue.f8ef7c80.js";import"./PhWebhooksLogo.vue.aa4763f4.js";import"./api.3d221a29.js";import"./runnerData.49bf6701.js";import"./url.4683fc99.js";import"./TabPane.8e50b74a.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="54477f8e-e134-4424-91dc-d1278ce09a73",t._sentryDebugIdIdentifier="sentry-dbid-54477f8e-e134-4424-91dc-d1278ce09a73")}catch{}})();const z={key:0,class:"home-container"},B=w({__name:"Home",setup(t){const n=x(),c=T(),d=b(()=>{var a;return((a=c.state.workspace)==null?void 0:a.sidebar.filter(l=>l.id!=="home"))||[]}),y=a=>{n.push({path:`/${a}`})};return(a,l)=>e(c).state.workspace?(s(),m("div",z,[o(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[d.value.length===0?(s(),p(e(f),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[u(" There are no forms available for you. ")]),_:1})):(s(!0),m(C,{key:1},D(d.value,i=>(s(),p(e(W),{key:i.id,class:"form-card",onClick:N=>y(i.path)},{default:r(()=>[o(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(s(),p(I(e(h)(i.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),o(e(f),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[u(F(i.name),1)]),_:2},1024),o(e(k),{size:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}),o(g,{class:"watermark","page-id":"home",locale:e(c).state.workspace.language},null,8,["locale"])])):v("",!0)}});const Q=H(B,[["__scopeId","data-v-2ee244f8"]]);export{Q as default};
//# sourceMappingURL=Home.2982ff45.js.map
