import{d as i,c as p,w as n,o as a,b as m,u as e}from"./vue-router.5e8ba7eb.js";import"./linters.fa5f4508.js";import{W as s}from"./workspaces.94798139.js";import{C as d}from"./ContentLayout.46908c65.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.99c7b027.js";import"./asyncComputed.bb3077bb.js";import"./runnerData.49bf6701.js";import"./url.4683fc99.js";import"./record.98df87df.js";import"./gateway.9bb9fef7.js";import"./popupNotifcation.b3ef9d8a.js";import"./fetch.7b08925d.js";import"./SaveButton.8f974eff.js";import"./ExclamationCircleOutlined.7ef2c090.js";import"./CrudView.d77e910d.js";import"./router.1e5228d6.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.af476096.js";import"./BookOutlined.bf415405.js";import"./PhDotsThree.vue.5061c9cb.js";import"./index.d0fd73d7.js";import"./index.806e571e.js";import"./PhRocketLaunch.vue.dc0dc724.js";import"./PhPencil.vue.3ceaa978.js";import"./index.c5acb39e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="409f22eb-dd34-4f0f-9538-ec7b23a1835a",o._sentryDebugIdIdentifier="sentry-dbid-409f22eb-dd34-4f0f-9538-ec7b23a1835a")}catch{}})();const z=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(t,u)=>(a(),p(d,null,{default:n(()=>[m(f,{"env-var-repository":e(r),mode:"editor","file-opender":e(s)},null,8,["env-var-repository","file-opender"])]),_:1}))}});export{z as default};
//# sourceMappingURL=EnvVarsEditor.9ffac371.js.map
