import{d as n,W as s,a,Z as d,er as r,o as l,$ as _}from"./vue-router.5e8ba7eb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="361d1254-a08e-4d8b-9677-f1a221cf6124",e._sentryDebugIdIdentifier="sentry-dbid-361d1254-a08e-4d8b-9677-f1a221cf6124")}catch{}})();const c={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(l(),s("div",c,[a("div",{class:r(["centered-layout",{"full-width":t.fullWidth}])},[d(t.$slots,"default",{},void 0,!0)],2)]))}});const i=_(u,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.46908c65.js.map
