import{a as g}from"./asyncComputed.bb3077bb.js";import{d as b,eu as y,V as _,u as e,c as w,W as x,b as a,w as o,o as l,cY as C,ax as p,d0 as h,bL as I,a as k,et as v}from"./vue-router.5e8ba7eb.js";import"./gateway.9bb9fef7.js";import{O as B}from"./organization.a9043c48.js";import"./tables.8dccf3c7.js";import{C as c}from"./router.1e5228d6.js";import{L as D}from"./LoadingContainer.c5ce29c9.js";import{A as N}from"./index.380cef28.js";import{C as z}from"./Card.c692bb57.js";import"./popupNotifcation.b3ef9d8a.js";import"./record.98df87df.js";import"./string.3bd1e390.js";import"./TabPane.8e50b74a.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="e29b758b-4190-4d6c-87b5-50b74b4dd1e7",t._sentryDebugIdIdentifier="sentry-dbid-e29b758b-4190-4d6c-87b5-50b74b4dd1e7")}catch{}})();const M={key:1},A={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},H=b({__name:"Billing",setup(t){const s=y().params.organizationId,{loading:u,result:f}=g(()=>B.get(s));_(()=>{location.search.includes("upgrade")&&c.showNewMessage("I want to upgrade my plan")});const m=()=>c.showNewMessage("I want to upgrade my plan");return(V,L)=>e(u)?(l(),w(D,{key:0})):(l(),x("div",M,[a(e(h),{justify:"space-between",align:"center"},{default:o(()=>[a(e(C),{level:3},{default:o(()=>[p("Current plan")]),_:1})]),_:1}),a(e(N),{style:{"margin-top":"0"}}),a(e(z),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(I),{onClick:m},{default:o(()=>[p("Upgrade")]),_:1})]),default:o(()=>{var r,i,d;return[k("div",A,v((d=(i=(r=e(f))==null?void 0:r.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{H as default};
//# sourceMappingURL=Billing.a63d927f.js.map
