import{_ as c}from"./Login.vue_vue_type_script_setup_true_lang.8314aa3a.js";import{u}from"./router.c3a5f38b.js";import{d as _,eH as i,eu as d,W as f,b as p,o as m,$ as y}from"./vue-router.5e8ba7eb.js";import"./CircularLoading.205967c8.js";import"./index.c5acb39e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="15c18b67-aab4-4345-8243-486f847c3e94",e._sentryDebugIdIdentifier="sentry-dbid-15c18b67-aab4-4345-8243-486f847c3e94")}catch{}})();const b={class:"runner"},l=_({__name:"Login",setup(e){const t=i(),o=d(),r=u(),a=async()=>{await r.signUp();const{redirect:s,...n}=o.query;if(s){await t.push({path:s,query:n,params:o.params});return}t.push({name:"playerHome",query:n})};return(s,n)=>(m(),f("div",b,[p(c,{onDone:a})]))}});const D=y(l,[["__scopeId","data-v-5b8c1f5f"]]);export{D as default};
//# sourceMappingURL=Login.111ecc1b.js.map
