import{O as d}from"./router.c3a5f38b.js";import{d as c,V as l,W as u,b as a,w as n,u as o,o as i,ax as s,cY as f,cX as _}from"./vue-router.5e8ba7eb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="dce7acec-4917-4a7f-a189-c2309ee9029f",e._sentryDebugIdIdentifier="sentry-dbid-dce7acec-4917-4a7f-a189-c2309ee9029f")}catch{}})();const w=c({__name:"OidcLogoutCallback",setup(e){return l(async()=>{await new d().logoutCallback()}),(t,r)=>(i(),u("div",null,[a(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(_),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.3bea14a1.js.map
