import{d as o,o as s,W as a,b as d,u as c,bp as r,$ as _}from"./vue-router.5e8ba7eb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="685e03c8-c7b1-4097-bfc9-2106efd0a77e",e._sentryDebugIdIdentifier="sentry-dbid-685e03c8-c7b1-4097-bfc9-2106efd0a77e")}catch{}})();const i={class:"centered"},f=o({__name:"LoadingContainer",setup(e){return(n,t)=>(s(),a("div",i,[d(c(r))]))}});const u=_(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.c5ce29c9.js.map
