import{L as x}from"./LoadingContainer.c5ce29c9.js";import{S as D}from"./SaveButton.8f974eff.js";import{C as h,W as A}from"./model.c9ad3cef.js";import{E as C}from"./api.73862ceb.js";import{d as W,e as E,f as N,u as t,c as n,W as _,R as y,b as d,w as o,o as r,a as w,aJ as B,ew as S,cX as k,ax as m,et as f,ex as V,cD as G,d0 as L,$ as T}from"./vue-router.5e8ba7eb.js";import{w as F}from"./metadata.0a8ceea8.js";import{a as M}from"./asyncComputed.bb3077bb.js";import{A as I}from"./index.806e571e.js";import{A as J}from"./index.380cef28.js";import"./ExclamationCircleOutlined.7ef2c090.js";import"./workspaces.94798139.js";import"./runnerData.49bf6701.js";import"./url.4683fc99.js";import"./record.98df87df.js";import"./validations.34e5855b.js";import"./string.3bd1e390.js";import"./PhArrowSquareOut.vue.bdda1139.js";import"./index.6a475b9c.js";import"./Badge.1de6f065.js";import"./isNumeric.75337b1e.js";import"./index.c5acb39e.js";import"./Card.c692bb57.js";import"./TabPane.8e50b74a.js";import"./uuid.c1fabc37.js";import"./fetch.7b08925d.js";import"./PhBug.vue.1aaf96e1.js";import"./PhCheckCircle.vue.0084ae07.js";import"./PhKanban.vue.f8ef7c80.js";import"./PhWebhooksLogo.vue.aa4763f4.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[i]="7c52a951-6b3e-4260-9548-4c8ceb883b6a",s._sentryDebugIdIdentifier="sentry-dbid-7c52a951-6b3e-4260-9548-4c8ceb883b6a")}catch{}})();const P={key:1,class:"workflow-editor"},R={class:"workflow-toolbar"},X=["onDragstart"],$=W({__name:"WorkflowEditor",setup(s){const i=E(null),u=N(()=>{var a;return(a=i.value)==null?void 0:a.gui}),v=new C,{result:l,loading:b}=M(()=>A.create(v)),g=(a,c)=>{var e,p;(e=c.dataTransfer)==null||e.setData("type",a),(p=u.value)==null||p.dragstart(a,c)};return(a,c)=>t(b)?(r(),n(x,{key:0})):(r(),_("div",P,[t(l)?(r(),n(h,{key:0,ref_key:"canvasGui",ref:i,model:t(l)},null,8,["model"])):y("",!0),d(t(L),null,{default:o(()=>[w("div",R,[(r(!0),_(B,null,S(t(F).stages,e=>(r(),n(t(G),{key:e.typeName,placement:"top"},{title:o(()=>[d(t(I),null,{default:o(()=>[d(t(k),null,{default:o(()=>[m(f(e.title),1)]),_:2},1024),d(t(k),{keyboard:""},{default:o(()=>[m(f(e.key),1)]),_:2},1024)]),_:2},1024)]),content:o(()=>[m(f(e.description),1)]),default:o(()=>[w("span",{draggable:"true",onDragstart:p=>g(e.typeName,p)},[(r(),n(V(e.icon),{width:"18",height:"18",class:"toolbar-item"}))],40,X)]),_:2},1024))),128)),d(t(J),{type:"vertical"}),t(l)?(r(),n(D,{key:0,model:t(l),disabled:void 0,type:"primary"},null,8,["model"])):y("",!0)])]),_:1})]))}});const vt=T($,[["__scopeId","data-v-de9c06f6"]]);export{vt as default};
//# sourceMappingURL=WorkflowEditor.f24ba1b2.js.map
