import{O as r}from"./router.c3a5f38b.js";import{d as l,V as c,W as i,b as t,w as n,u as o,o as u,ax as s,cY as f,cX as _}from"./vue-router.5e8ba7eb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="76d3e38e-a531-4fa4-b7cc-1810da0c3327",e._sentryDebugIdIdentifier="sentry-dbid-76d3e38e-a531-4fa4-b7cc-1810da0c3327")}catch{}})();const p=l({__name:"OidcLoginCallback",setup(e){return c(async()=>{await new r().loginCallback()}),(a,d)=>(u(),i("div",null,[t(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),t(o(_),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.754715ee.js.map
