import{P as l}from"./PlayerNavbar.1eec18ae.js";import{u as _,b}from"./router.c3a5f38b.js";import{d as f,eH as h,eu as s,f as g,r as y,W as v,b as r,u as i,a as w,o as L,$ as I}from"./vue-router.5e8ba7eb.js";import"./metadata.0a8ceea8.js";import"./PhBug.vue.1aaf96e1.js";import"./PhCheckCircle.vue.0084ae07.js";import"./PhKanban.vue.f8ef7c80.js";import"./PhWebhooksLogo.vue.aa4763f4.js";import"./PhSignOut.vue.70d2e442.js";import"./workspaceStore.f173667e.js";import"./api.3d221a29.js";import"./runnerData.49bf6701.js";import"./url.4683fc99.js";import"./index.96dc97c0.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="fb36427c-d5bd-4b1a-a5b7-35d9eaab4bad",t._sentryDebugIdIdentifier="sentry-dbid-fb36427c-d5bd-4b1a-a5b7-35d9eaab4bad")}catch{}})();const k={class:"main-container"},N={class:"content"},x=f({__name:"Main",setup(t){const e=h(),o=_(),c=s().path,d=({path:a})=>{e.push({path:`/${a}`})},u=()=>{e.push({name:"playerLogin"})},p=g(()=>!!s().meta.hideLogin);return b(()=>e.push({name:"playerLogin"})),(a,C)=>{var n;const m=y("RouterView");return L(),v("div",k,[r(l,{"current-path":i(c),"user-email":(n=i(o).user)==null?void 0:n.claims.email,"hide-login":p.value,onNavigate:d,onLoginClick:u},null,8,["current-path","user-email","hide-login"]),w("section",N,[r(m)])])}}});const z=I(x,[["__scopeId","data-v-9c4cb6a6"]]);export{z as default};
//# sourceMappingURL=Main.9a216dbc.js.map
