import{b as c,ey as o,eS as u}from"./vue-router.5e8ba7eb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="97889774-fcbc-4369-83d4-ced646eb94cc",e._sentryDebugIdIdentifier="sentry-dbid-97889774-fcbc-4369-83d4-ced646eb94cc")}catch{}})();function a(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(i){return Object.getOwnPropertyDescriptor(n,i).enumerable}))),r.forEach(function(i){f(e,i,n[i])})}return e}function f(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var d=function(t,n){var r=a({},t,n.attrs);return c(o,a({},r,{icon:u}),null)};d.displayName="LoadingOutlined";d.inheritAttrs=!1;const s=d;export{s as L};
//# sourceMappingURL=LoadingOutlined.ddf38866.js.map
